# Load all scripts
. $PSScriptRoot\Provider.ps1
. $PSScriptRoot\Formats.ps1
. $PSScriptRoot\Hierarchy.ps1

# Load format files into current session
Get-ChildItem $PSScriptRoot\FormatData\*.ps1xml | 
	ForEach-Object { Update-FormatData $_ -ErrorAction SilentlyContinue }


# Setting aliases
<# Aliases for internal module nouns
	cm   ConfigMgr 
	o    Object
	p    Package
	a    Advertisement
	srl  SystemResourceList
	pdp  Package (on/from) Distribution Point
	dpg  Distribution Point Group
	c    Collection
	s    Site
#>

# Aliases from Provider.ps1 file
Set-Alias -Name cccm    -Value Connect-ConfigMgrProvider
Set-Alias -Name dccm    -Value Disconnect-ConfigMgrProvider
Set-Alias -Name rdcm    -Value Read-ConfigMgrProviderSettings

# Aliases from Hierarchy.ps1
Set-Alias -Name gcmsrl	-Value Get-ConfigMgrSystemResourceList
Set-Alias -Name gcms	-Value Get-ConfigMgrSite

# Exporting members
Export-ModuleMember -Function Connect-ConfigMgrProvider
Export-ModuleMember -Function Read-ConfigMgrProviderSettings
Export-ModuleMember -Function Disconnect-ConfigMgrProvider
Export-ModuleMember -Function Get-ConfigMgrObject
Export-ModuleMember -Function Get-ConfigMgrSystemResourceList
Export-ModuleMember -Function Get-ConfigMgrSite

Export-ModuleMember -Alias *

[bool]$Global:PSCMXGenerateFormatFile = $true

# Name to Class mapping
$Script:NameToClass = @{
	'Collection'    = 'SMS_Collection'
	'Advertisement' = 'SMS_Advertisement'
	'Site'          = 'SMS_Site'
    'SystemResourceList' = 'SMS_SystemResourceList'
}